# package_name

Description. 
The package bank_sys is used to:
	- Bank Transations

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install bank_sysia
```

## Usage

```python
from bank_sys import bank
```

## Author
Mats

## License
[MIT](https://choosealicense.com/licenses/mit/)